==> tomoko-kernel-0.0.8.tgz: package/util/lang.js <==
/**
 * @authors       gebilaoxiong
 * @email         gebilaoxiong@gmail.com
 * @date          2016-06-20 22:49:34
 * @description   语言扩展
 */

var _ = require('lodash'),

  arraySlice = Array.prototype.slice,

  lang = module.exports;


/**
 * 将source的成员混淆到target中
 * @type {Object}           target          
 * @type {Object}           source          
 */
lang.extend = _.assignIn;


/**
 * 类型判断函数
 */
'String Array Number Boolean Date Function RegExp Object'.split(' ')
  .forEach(function(method) {
    method = 'is' + _.capitalize(method);
    lang[method] = _[method];
  });



[
  /* 属性访问器 */
  'get',

  /* 属性赋值器 */
  'set',

  /* 转换为数组 */
  'toArray'
]
.forEach(function(method) {

  lang[method] = _[method];

});


/**
 * 字符串处理:pad
 * @param  {String}                   str               需要处理的字符串
 * @param  {Number}                   len               长度
 * @param  {String}                   fill              填充文本
 * @param  {Boolean}                  pre               填充方向 默认为左
 */
lang.pad = function(str, len, fill, pre) {

  if (str.length < len) {
    // 填充文本
    fill = Array(len).join(fill || ' ');

    if (pre) {
      str = (fill + str).slice(-len);
    } else {
      str = (str + fill).subString(0, len);
    }
  }

  return str;
}


/**
 * 类型定义工厂
 */
lang.define = function( /* parent, [partial]... */ ) {
  var parmas = arraySlice.call(arguments, 0),
    parent, klass;

  // parent
  if (lang.isFunction(parmas[0])) {
    parent = parmas.shift();
  }

  // 类型
  klass = function() {
    var me = this;
    me.init.apply(me, arguments);
  }

  // 继承基类
  if (parent) {
    proto.prototype = parent.prototype;
    klass.prototype = new proto();
    klass.prototype.constructor = klass;
    klass.super = parent;
  }

  // 扩展原型
  parmas.forEach(function(partial) {
    lang.extend(klass.prototype, partial);
  });

  return klass;
}

function proto() {}


/**
 * 合并配置参数
 */
lang.mergeOptions = function() {
  var options = {};

  _.toArray(arguments).forEach(function(partial) {
    options = _.mergeWith(options, partial, optionCustomizer)
  });

  return options;
}

// 参数合并策略
function optionCustomizer(left, right) {
  if (_.isArray(left)) {
    return left.concat(right);
  }
}

==> tomoko-kernel-0.0.9.tgz: package/util/lang.js <==
/**
 * @authors       gebilaoxiong
 * @email         gebilaoxiong@gmail.com
 * @date          2016-06-20 22:49:34
 * @description   语言扩展
 */

var _ = require('lodash'),

  arraySlice = Array.prototype.slice,

  lang = exports;


/**
 * 将source的成员混淆到target中
 * @type {Object}           target          
 * @type {Object}           source          
 */
lang.extend = _.assignIn;


/**
 * 类型判断函数
 */
'String Array Number Boolean Date Function RegExp Object'.split(' ')
  .forEach(function(method) {
    method = 'is' + _.capitalize(method);
    lang[method] = _[method];
  });



[
  /* 属性访问器 */
  'get',

  /* 属性赋值器 */
  'set',

  /* 转换为数组 */
  'toArray'
]
.forEach(function(method) {

  lang[method] = _[method];

});


/**
 * 字符串处理:pad
 * @param  {String}                   str               需要处理的字符串
 * @param  {Number}                   len               长度
 * @param  {String}                   fill              填充文本
 * @param  {Boolean}                  pre               填充方向 默认为左
 */
lang.pad = function(str, len, fill, pre) {

  if (str.length < len) {
    // 填充文本
    fill = Array(len).join(fill || ' ');

    if (pre) {
      str = (fill + str).slice(-len);
    } else {
      str = (str + fill).substring(0, len);
    }
  }

  return str;
}


/**
 * 类型定义工厂
 */
lang.define = function( /* parent, [partial]... */ ) {
  var parmas = arraySlice.call(arguments, 0),
    parent, klass;

  // parent
  if (lang.isFunction(parmas[0])) {
    parent = parmas.shift();
  }

  // 类型
  klass = function() {
    var me = this;
    me.init.apply(me, arguments);
  }

  // 继承基类
  if (parent) {
    proto.prototype = parent.prototype;
    klass.prototype = new proto();
    klass.prototype.constructor = klass;
    klass.super = parent;
  }

  // 扩展原型
  parmas.forEach(function(partial) {
    lang.extend(klass.prototype, partial);
  });

  return klass;
}

function proto() {}


/**
 * 合并配置参数
 */
lang.mergeOptions = function() {
  var options = {};

  _.toArray(arguments).forEach(function(partial) {
    options = _.mergeWith(options, partial, optionCustomizer)
  });

  return options;
}

// 参数合并策略
function optionCustomizer(left, right) {
  if (_.isArray(left)) {
    return left.concat(right);
  }
}
